package ru.ulstu.fc.project.service;

import org.springframework.stereotype.Service;
import ru.ulstu.fc.project.model.Project;
import ru.ulstu.fc.project.model.ProjectForm;
import ru.ulstu.fc.project.repository.ProjectRepository;

import java.util.List;

@Service
public class ProjectService {
    private final ProjectRepository projectRepository;

    public ProjectService(ProjectRepository projectRepository) {
        this.projectRepository = projectRepository;
    }

    public List<Project> getCurrentUserProjects() {
        return projectRepository.findAll();
    }

    public Project save(ProjectForm projectForm) {
        return projectRepository.save(new Project(projectForm));
    }

    public Project save(Project projectToSave) {
        if (projectToSave.getId() == null) {
            return projectRepository.save(projectToSave);
        }
        Project dbProject = projectRepository
                .findById(projectToSave.getId())
                .orElseThrow(() -> new RuntimeException("Project not found by id"));
        dbProject.setName(projectToSave.getName());
        return projectRepository.save(dbProject);
    }

    public void delete(ProjectForm projectForm) {
        projectRepository.deleteById(projectForm.getId());
    }

    private void checkUserProjectWithThrow(Project project) {
        if (!isUserProject(project)) {
            throw new RuntimeException("User can not get access to project");
        }
    }

    private boolean isUserProject(Project project) {
        return (userSevice.getCurrentUser().equals(project.getUser()));
    }
}
